@@ -738,7 +738,7 @@ process_utree(Unit_t *t)
     simplify_unit(Pstack[Ptopidx]);
     //Pstack[Ptopidx]->u_symbol[0]='\0';
     //fprintf(stderr,Pstack[Ptopidx]->u_symbol,"");
-    print_unit_t(Pstack[Ptopidx]);
+    //print_unit_t(Pstack[Ptopidx]);
     //u_find_name(Pstack[Ptopidx]);
     //print_matches(Pstack[Ptopidx]);
     return(Pstack[Ptopidx]);
