@@ -13,10 +13,10 @@
  * (1) https://ckeditor.com/cke4/builder
  *     Visit online builder to build CKEditor from scratch.
  *
- * (2) https://ckeditor.com/cke4/builder/56077422f2408db1cc42bffc767cd7ee
+ * (2) https://ckeditor.com/cke4/builder/16e5b5263f49678ff222955a00d94c05
  *     Visit online builder to build CKEditor, starting with the same setup as before.
  *
- * (3) https://ckeditor.com/cke4/builder/download/56077422f2408db1cc42bffc767cd7ee
+ * (3) https://ckeditor.com/cke4/builder/download/16e5b5263f49678ff222955a00d94c05
  *     Straight download link to the latest version of CKEditor (Optimized) with the same setup as before.
  *
  * NOTE:
@@ -41,7 +41,6 @@ var CKBUILDER_CONFIG = {
 		'.npm',
 		'.nvmrc',
 		'.travis.yml',
-		'README.md',
 		'bender-err.log',
 		'bender-out.log',
 		'bender-runner.config.json',
@@ -114,6 +113,7 @@ var CKBUILDER_CONFIG = {
 		'pt-br' : 1,
 		'ru' : 1,
 		'tr' : 1,
-		'zh' : 1
+		'zh' : 1,
+		'zh-cn' : 1
 	}
 };
\ No newline at end of file
