@@ -1,6 +1,6 @@
 # The LearningOnline Network
 #
-# $Id: Lond.pm,v 1.8.2.2 2021/02/10 15:08:14 raeburn Exp $
+# $Id: Lond.pm,v 1.8.2.3 2022/01/19 16:47:51 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -239,10 +239,10 @@ sub check_homecourses {
                     }
                 }
                 unless (&untie_domain_hash($hashref)) {
-                    &logthis("Failed to untie tied hash for nohist_courseids.db for $domain");
+                    &Apache::lonnet::logthis("Failed to untie tied hash for nohist_courseids.db for $domain");
                 }
             } else {
-                &logthis("Failed to tie hash for nohist_courseids.db for $domain");
+                &Apache::lonnet::logthis("Failed to tie hash for nohist_courseids.db for $domain");
             }
         }
         foreach my $hashid (keys(%recent)) {
@@ -314,9 +314,9 @@ sub get_courseinfo_hash {
     };
     if ($@) {
         if ($@ eq "timeout\n") {
-            &logthis("<font color='blue'>WARNING courseiddump for $cnum:$cdom from $home timedout</font>");
+            &Apache::lonnet::logthis("<font color='blue'>WARNING courseiddump for $cnum:$cdom from $home timedout</font>");
         } else {
-            &logthis("<font color='yellow'>WARNING unexpected error during eval of call for courseiddump from $home</font>");
+            &Apache::lonnet::logthis("<font color='yellow'>WARNING unexpected error during eval of call for courseiddump from $home</font>");
         }
     } else {
         if (ref($info{$cdom.'_'.$cnum}) eq 'HASH') {
@@ -802,10 +802,10 @@ sub is_course {
             }
             &Apache::lonnet::do_cache_new('iscourse',$hashid,$iscourse,3600);
             unless (&untie_domain_hash($hashref)) {
-                &logthis("Failed to untie tied hash for nohist_courseids.db for $cdom");
+                &Apache::lonnet::logthis("Failed to untie tied hash for nohist_courseids.db for $cdom");
             }
         } else {
-            &logthis("Failed to tie hash for nohist_courseids.db for $cdom");
+            &Apache::lonnet::logthis("Failed to tie hash for nohist_courseids.db for $cdom");
         }
     }
     return $iscourse;
