@@ -1,7 +1,7 @@
 #   This module defines and implements a class that represents
 #   a connection to a lond daemon.
 #
-# $Id: LondConnection.pm,v 1.53 2012/10/01 11:00:43 foxr Exp $
+# $Id: LondConnection.pm,v 1.53.2.1 2018/09/02 18:30:54 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1160,6 +1160,15 @@ sub GetClientData {
     return $self->{ClientData};
 }
 
+#
+# Get the HostID of our peer 
+#
+
+sub PeerLoncapaHim {
+    my $self = shift;
+    return $self->{LoncapaHim};
+}
+
 1;
 
 =pod
