@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.158.2.15 2022/02/24 16:00:23 raeburn Exp $
+# $Id: lonlogin.pm,v 1.158.2.17 2024/07/13 20:59:10 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -968,7 +968,7 @@ sub redirect_page {
         $url .='?firsturl='.$querystring;
     }
     my $start_page = &Apache::loncommon::start_page('Switching Server ...',undef,
-                                                    {'redirect' => [0,$url],});
+                                                    {'redirect' => [0,$url,'',1]});
     my $end_page   = &Apache::loncommon::end_page();
     return $start_page.$end_page;
 }
