@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Access Handler for User File Transfers
 #
-# $Id: lontokacc.pm,v 1.19 2007/05/16 09:45:58 albertel Exp $
+# $Id: lontokacc.pm,v 1.20 2020/12/18 15:23:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -36,7 +36,7 @@ use IO::Socket;
 
 sub handler {
     my $r = shift;
-    my $reqhost = $r->get_remote_host(REMOTE_NOLOOKUP);
+    my $reqhost = &Apache::lonnet::get_requestor_ip($r,REMOTE_NOLOOKUP,1);
     my @hostids= &Apache::lonnet::get_hosts_from_ip($reqhost);
     if (!@hostids && $reqhost ne '127.0.0.1' ) {
 	$r->log_reason("Unable to find a host for ".
