@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Passphrase Entry and Validation for Portfolio files 
 #
-# $Id: restrictedaccess.pm,v 1.8 2009/02/13 17:20:26 bisitz Exp $
+# $Id: restrictedaccess.pm,v 1.10 2013/07/15 14:32:47 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -55,7 +55,8 @@ sub handler {
 					   $origurl);
 	    $env{'request.state'} = "published";
 	    $env{'request.filename'} = $origurl;
-	    $r->header_out(Location => 'http://'.$ENV{'HTTP_HOST'}.$origurl);
+            my $newurl = &Apache::lonnet::absolute_url($ENV{'HTTP_HOST'}).$origurl;
+	    $r->header_out(Location => $newurl);
 	    return REDIRECT;
         } else {
 	    $msg = 'Invalid passphrase';
@@ -105,7 +106,7 @@ function verify() {
     $r->print(&Apache::loncommon::start_data_table_row());
     $r->print('<td align="center" colspan="2"><br />'.
               '<input type="button" name="sendpass" value="'.
-              &mt('Submit passphrase').'" onClick="verify()" /></td>');
+              &mt('Submit passphrase').'" onclick="verify()" /></td>');
     $r->print(&Apache::loncommon::end_data_table_row());
     $r->print(&Apache::loncommon::end_data_table());
     $r->print('<input type="hidden" name="origurl" value="'.
