@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Switch Servers Handler
 #
-# $Id: switchserver.pm,v 1.35.2.7 2024/07/02 19:42:06 raeburn Exp $
+# $Id: switchserver.pm,v 1.35.2.9 2024/10/09 15:33:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -31,6 +31,8 @@ package Apache::switchserver;
 use strict;
 use Apache::Constants qw(:common :remotehost);
 use Apache::lonnet;
+use Apache::loncommon;
+use Apache::lonmenu;
 use Digest::MD5 qw(md5_hex);
 use CGI::Cookie();
 use Apache::lonlocal;
@@ -63,7 +65,10 @@ sub do_redirect {
     my $start_page = 
 	&Apache::loncommon::start_page('Switching Server ...',undef,
 				       {'redirect'       => [$delay,$url,'',1],
-					'only_body'      => $only_body,});
+					'only_body'      => $only_body,
+                                        'switchserver'   => 1,
+                                        'links_disabled' => 1,
+                                        'no_inline_link' => 1,});
     my $end_page   = &Apache::loncommon::end_page();
     $r->print($start_page.$extra_text.$end_page);
     unless ($env{'user.name'} eq 'public' && ($env{'user.domain'} eq 'public')) {
@@ -267,6 +272,8 @@ sub handler {
     }
 # -------------------------------------------------------- Menu script and info
 
+    my $windowinfo = &Apache::lonmenu::close();
+
 # ---------------------------------------------------------------- Get handover
 
     my ($is_balancer,$setcookie,$newcookieid,$otherbalcookie);
@@ -333,7 +340,7 @@ sub handler {
 	'&amp;username='.$env{'user.name'}.
 	'&amp;token='.$token;
 # --------------------------------------------------------------- Screen Output
-    return &do_redirect($r, $url, $only_body, $ssologoutscript);
+    return &do_redirect($r, $url, $only_body, $windowinfo.$ssologoutscript);
 }
 
 1;
