@@ -2,7 +2,7 @@
 #
 # Automated Course Creation script
 #
-# $Id: Autocreate.pl,v 1.20 2016/11/16 18:09:21 raeburn Exp $
+# $Id: Autocreate.pl,v 1.21 2019/07/26 02:28:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -175,7 +175,8 @@ sub process_xml {
     closedir(DIR);
     my %courseids = ();
     print $fh "Sending to batch - auto,$dom,$dcname,$dcdom ".join(":",@requests)."\n";
-    my ($result,$logmsg) = &LONCAPA::batchcreatecourse::create_courses(\@requests,\%courseids,'auto',$dom,$dcname,$dcdom);
+    my ($result,$logmsg,$keysmsg,$codesref,$instcodesref) =
+        &LONCAPA::batchcreatecourse::create_courses(\@requests,\%courseids,'auto',$dom,$dcname,$dcdom);
     my $outcome;
     if ($result ne '') {
         $outcome = $result."\n";
@@ -183,6 +184,9 @@ sub process_xml {
     if ($logmsg ne '') {
         $outcome .= $logmsg."\n";    
     }
+    if ($keysmsg ne '') {
+        $outcome .=  $keysmsg."\n";
+    }
     print $fh $outcome;
 
     my $output;
@@ -210,6 +214,22 @@ sub process_xml {
     }
     $output =~ s/:$//;
     &unset_dc_env();
+    if (ref($instcodesref) eq 'HASH') {
+        if (keys(%{$instcodesref}) > 0) {
+            &Apache::lonnet::devalidate_cache_new('instcats',$dom);
+            if (&Apache::lonnet::shared_institution($dom)) {
+                my %servers = &Apache::lonnet::internet_dom_servers($dom);
+                my %thismachine;
+                map { $thismachine{$_} = 1; } &Apache::lonnet::current_machine_ids();
+                if (keys(%servers)) {
+                    foreach my $server (keys(%servers)) {
+                        next if ($thismachine{$server});
+                        &Apache::lonnet::remote_devalidate_cache($server,['instcats:'.$dom]);
+                    }
+                }
+            }
+        }
+    }
     return $output;
 }
 
