@@ -1,5 +1,5 @@
 #
-# $Id: batchcreatecourse.pm,v 1.40.2.1 2016/09/01 01:05:05 raeburn Exp $
+# $Id: batchcreatecourse.pm,v 1.40.2.3 2020/05/22 20:55:45 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -89,6 +89,7 @@ use strict;
 # <disresdis>1</disresdis>
 # <disablechat>1</disablechat>
 # <openall></openall>
+# <openallfrom></openallfrom>
 # <notify_dc>1</notify_dc>
 # <notify_owner>1</notify_owner>
 # <owner>
@@ -211,7 +212,7 @@ sub create_courses {
             $longroles{'Community'}{$1} = $3;
         }
     }
-    my ($logmsg,$keysmsg,$newusermsg,$addresult,%codehash);
+    my ($logmsg,$keysmsg,$newusermsg,$addresult,%codehash,%instcodes);
     my %enrollcount = ();
     my $newcoursedir = LONCAPA::tempdir().'/addcourse/'.$dom.'/'.$context;
     if ($context eq 'auto') {
@@ -239,12 +240,15 @@ sub create_courses {
                         if ($code) {
                             $codehash{$courseid} = $code;
                         }
+                        if ($details{$num}{'coursecode'} ne '') {
+                            push(@{$instcodes{$details{$num}{'coursecode'}}},$courseid);
+                        }
                     }
                 }
             }
         }
     }
-    return ($output,$logmsg,$keysmsg,\%codehash);
+    return ($output,$logmsg,$keysmsg,\%codehash,\%instcodes);
 }
 
 #############################################################
@@ -269,7 +273,7 @@ sub parse_coursereqs {
     my $role = '';
     my @items = ('title','optional_id','coursecode','defaultcredits','coursehome','reshome','nonstandard','adds','drops','topmap','firstres','clonecrs','clonedom','datemode','dateshift','showphotos','setpolicy','setcontent','setcomment','setkeys','keyauth','disresdis','disablechat','openall','notify_owner','notify_dc','crstype','crsquota','uniquecode');
     my @possroles = qw(st ad ep ta in cc co);
-    my @dateitems = ('enrollstart','enrollend','accessstart','accessend');
+    my @dateitems = ('enrollstart','enrollend','accessstart','accessend','openallfrom');
     my @useritems = ('autharg','authtype','firstname','generation','lastname','middlename','studentID');
     my $p = HTML::Parser->new
     (
@@ -542,6 +546,7 @@ sub build_course {
                disresdis => $details->{'disresdis'},
                disablechat => $details->{'disablechat'},
                openall => $details->{'openall'},
+               openallfrom => $details->{'openallfrom'},
                firstres => $firstres
                };
         if ($details->{'textbook'}) {
