@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 $|=1;
 # User Status
-# $Id: userstatus.pl,v 1.20 2010/03/23 12:01:49 bisitz Exp $
+# $Id: userstatus.pl,v 1.23 2021/03/07 02:34:25 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -114,6 +114,7 @@ sub main {
                   Course              => 'Course',
                   Browser             => 'Browser',
                   OS                  => 'OS',
+                  Any                 => 'Any',
                   Active              => 'Active',
                   'Moderately Active' => 'Moderately Active',
                   Inactive            => 'Inactive',
@@ -137,6 +138,7 @@ sub main {
     foreach my $filename (@allfiles) {
 	if ($filename=~/^\./) { next; }
 	if ($filename=~/^publicuser_/) { next; }
+        if ($filename=~/^[a-f0-9]+_(linked|lti_\d+)\.id$/) { next; }
 	my ($dev,$ino,$mode,$nlink,
 	    $uid,$gid,$rdev,$size,
 	    $atime,$mtime,$ctime,
@@ -266,7 +268,7 @@ sub showact {
     print("<h3>$ltref->{$cat}</h3>\n");
     
     print("<table border='1'><tr><th>&nbsp;</th><th>");
-    print(join("</th><th>",('Any',@actl)));
+    print(join("</th><th>",map {$ltref->{$_};} ('Any',@actl)));
     print("</th></tr>");
     foreach my $type (sort(keys(%{$usercount{$cat}}))) {
 	print("<tr><td>$type</td>");
