@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # chemical equation style response
 #
-# $Id: chemresponse.pm,v 1.101 2021/12/24 11:07:42 raeburn Exp $
+# $Id: chemresponse.pm,v 1.102 2023/06/26 14:24:15 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -217,7 +217,7 @@ function submitSmiles() {
     }
 }
 function openHelpWindow() {
-    window.open("http://peter-ertl.com/jsme/2013_03/help.html","","scrollbars=yes,resizable=yes,width=500,height=600");
+    window.open("https://jsme-editor.github.io/help.html","","scrollbars=yes,resizable=yes,width=500,height=600");
 }
 
 </script>
