@@ -2,7 +2,7 @@
 # The LearningOnline Network with CAPA
 # Dynamically converts JME strings into either a png or ps file.
 #
-# $Id: convertjme.pl,v 1.16 2011/07/04 09:24:54 foxr Exp $
+# $Id: convertjme.pl,v 1.17 2024/06/02 10:52:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -131,7 +131,7 @@ if ($png) {
 				 ysize => $ymax-$ymin+2,
 				 clip => 1,
 				 eps => 1,
-				 color => 0,
+				 colour => 1,
 				 units => "cm");
 }
 
