@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.344.2.10 2018/09/21 04:37:36 raeburn Exp $
+# $Id: lonhomework.pm,v 1.344.2.11 2024/07/08 01:13:59 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -850,7 +850,7 @@ STATE
 
 sub analyze_header {
     my ($request) = @_;
-    my $js = &Apache::structuretags::setmode_javascript();
+    my $js = &Apache::lonxml::setmode_javascript();
 
     # Breadcrumbs
     my $brcrum = [{'href' => &Apache::loncommon::authorspace($request->uri),
@@ -1083,7 +1083,7 @@ sub editxmlmode {
 	my $js =
 	    &Apache::edit::js_change_detection(). 
 	    &Apache::loncommon::resize_textarea_js().
-            &Apache::structuretags::setmode_javascript().
+            &Apache::lonxml::setmode_javascript().
             &Apache::lonhtmlcommon::dragmath_js("EditMathPopup");
 
     # Breadcrumbs
