@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # tags that create controlled output
 #
-# $Id: outputtags.pm,v 1.58.4.1 2018/09/11 14:39:47 raeburn Exp $
+# $Id: outputtags.pm,v 1.58.4.2 2024/07/03 22:38:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -308,7 +308,7 @@ sub start_displaystudentphoto {
 	my $args;
 	my $width=&Apache::lonxml::get_param('width',$parstack,$safeeval);
 	if ($width) { $args.=" width=\"$width\" "; }
-	my $height=&Apache::lonxml::get_param('heigth',$parstack,$safeeval);
+	my $height=&Apache::lonxml::get_param('height',$parstack,$safeeval);
 	if ($height) { $args.=" height=\"$height\" "; }
 	my $align=&Apache::lonxml::get_param('align',$parstack,$safeeval);
 	if ($align) { $args.=" align=\"$align\" "; }
