@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # mutliple choice style responses
 #
-# $Id: radiobuttonresponse.pm,v 1.157.2.2 2016/09/14 18:18:51 raeburn Exp $
+# $Id: radiobuttonresponse.pm,v 1.157.2.3 2019/02/03 22:02:21 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1030,7 +1030,8 @@ sub display_latex_exam {
 		. '} \hspace*{\fill} \\\\';
 	}
 	else {
-	    $result .= '\textbf{' . $Apache::lonxml::counter . '}.';
+	    $result .= '\textbf{' . $Apache::lonxml::counter . '}.'.
+                       '\hspace*{2 mm}';        
 	}
 	
 	# Now output the bubbles themselves:
@@ -1047,7 +1048,15 @@ sub display_latex_exam {
 	    }
 	    my $preindent;
 	    if ($bubble_number > 0) {
-		$preindent = '\hspace*{3 mm}';
+                my $offset = 5;
+                if ($Apache::lonxml::counter) {
+                    if ($identifier) {
+                        $offset += 2 * (length($identifier)-1);
+                    } else {
+                        $offset += 2 * (length($Apache::lonxml::counter)-1);
+                    }
+                }
+                $preindent = '\hspace*{'.$offset.' mm}';
 	    }
 	    my $foiltext = $Apache::response::foilgroup{$name . '.text'};
 	    $foiltext =~ s/\\noindent//; # forgive me for I have sinned..
