@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.244.2.4 2024/07/02 00:40:42 raeburn Exp $
+# $Id: response.pm,v 1.244.2.5 2024/10/29 03:29:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -880,7 +880,7 @@ sub answer_part {
     if ($env{'form.answer_output_mode'} eq 'tex') {
 	if (!$args->{'no_verbatim'}) {
 	    my $to_use='|';
-	    foreach my $value (32..126) {
+	    foreach my $value (33..41,43..126) {
 		my $char=pack('c',$value);
 		if ($answer !~ /\Q$char\E/) {
 		    $to_use=$char;
