@@ -47,7 +47,7 @@ CKEDITOR.editorConfig = function( config ) {
     
     
     config.allowedContent = true;
-    config.extraPlugins = 'lcm,chem';
+    config.extraPlugins = 'balloonpanel,a11ychecker,lcm,chem';
     
     config.mathJaxLib = '/adm/MathJax/MathJax.js?config=TeX-AMS-MML_HTMLorMML';
     
@@ -133,5 +133,7 @@ CKEDITOR.editorConfig = function( config ) {
         'rose.png','food-pizza.png','face-ninja.png', 'face-pirate.png', 'opinion-agree.png',
         'opinion-disagree.png', 'face-angel.png'
     ];
+
+    config.versionCheck = false; 
     
 };
