@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Utilities for classifying courses based on institutional code
 #
-# $Id: courseclassifier.pm,v 1.27 2019/07/23 13:58:53 raeburn Exp $
+# $Id: courseclassifier.pm,v 1.30 2023/07/10 01:55:15 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -69,7 +69,8 @@ sub recurse_list {
                     push @{$$idarrays{$$codetitles[2]}{$$codes{$cid}{$$codetitles[0]}}{$$codes{$cid}{$$codetitles[1]}}}, $$codes{$cid}{$$codetitles[2]};
                 }
             } else {
-                @{$$idarrays{$$codetitles[2]}{$$codes{$cid}{$$codetitles[0]}}{$$codes{$cid}{$$codetitles[1]}}} = ("$$codes{$cid}{$$codetitles[2]}");            }
+                @{$$idarrays{$$codetitles[2]}{$$codes{$cid}{$$codetitles[0]}}{$$codes{$cid}{$$codetitles[1]}}} = ("$$codes{$cid}{$$codetitles[2]}");
+            }
         } else {
             %{$$idarrays{$$codetitles[2]}{$$codes{$cid}{$$codetitles[0]}}} = ();
             @{$$idarrays{$$codetitles[2]}{$$codes{$cid}{$$codetitles[0]}}{$$codes{$cid}{$$codetitles[1]}}} = ("$$codes{$cid}{$$codetitles[2]}");
@@ -402,7 +403,6 @@ function toggleSecVis() {
         showlist = 'inline';
         showbox = 'none';
     }
-    alert("crscode is ||"+crscode+"|| and currcode is ||"+currcode+"|| and showlist is ||"+showlist+"|| and showbox is ||"+showbox+"||");
     if (document.getElementById('LC_helpdesk_sectionlist')) {
         document.getElementById('LC_helpdesk_sectionlist').style.display = showlist;
     }
@@ -528,9 +528,12 @@ sub instcode_selectors_data {
             %{$cat_titles} = %{$instcats->{'cat_titles'}};
             %{$cat_order} = %{$instcats->{'cat_order'}};
             $totcodes = scalar(keys(%{$codes}));
+            if ((!$totcodes) && (exists($instcats->{'totcodes'}))) {
+                $totcodes = $instcats->{'totcodes'};
+            }
             &build_code_selections($codes,$codetitles,$cat_titles,$cat_order,
                                    \%idlist,\%idnums,\%idlist_titles);
-            my ($scripttext,$longtitles) = 
+            my ($scripttext,$longtitles) =
                 &javascript_definitions($codetitles,\%idlist,\%idlist_titles,
                                         \%idnums,$cat_titles);
             my $longtitles_str = join('","',@{$longtitles});
