@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # entity -> tex.
 #
-# $Id: entities.pm,v 1.22 2014/10/14 18:30:23 raeburn Exp $
+# $Id: entities.pm,v 1.23 2019/02/23 20:05:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -650,6 +650,8 @@ my %entities = (
     'real'   => '\ensuremath{\Re}',
     8482     => '\texttrademark',
     'trade'  => '\texttrademark',
+    8496     => '\ensuremath{\mathcal{E}}',
+    'expectation' => '\ensuremath{\mathcal{E}}',
     8501     => '\ensuremath{\aleph}',
     'alefsym'=> '\ensuremath{\aleph}',
 
