@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Group Bulletin Boards Manager
 #
-# $Id: groupboards.pm,v 1.21 2013/11/23 20:40:57 raeburn Exp $
+# $Id: groupboards.pm,v 1.23 2020/09/08 23:54:40 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,6 +33,8 @@ use Apache::Constants qw(:common :http);
 use Apache::loncommon();
 use Apache::lonnet;
 use Apache::lonuserstate();
+use Apache::longroup;
+use Apache::lonnavmaps;
 use LONCAPA::map();
 use Apache::lonlocal;
 use LONCAPA;
@@ -257,14 +259,27 @@ sub boards_header {
           text=>"Groups",
           title=>"View course groups"},);
     }
+    my $view_permission =
+          &Apache::lonnet::allowed('vcg',$env{'request.course.id'}.($env{'request.course.sec'}?'/'.$env{'request.course.sec'}:''));
+    my $navmap=Apache::lonnavmaps::navmap->new();
+    my $grouppagelink = &Apache::longroup::get_group_link($cdom,$cnum,$group,$navmap,$view_permission,$refarg);
+    if ($grouppagelink) {
+        &Apache::lonhtmlcommon::add_breadcrumb
+            ({href=>$grouppagelink,
+              text=>&mt('Group').": $description",
+              title=>&mt("Go to group's home page"),
+              no_mt=>1});
+    } else {
+        &Apache::lonhtmlcommon::add_breadcrumb
+            ({text=>&mt('Group').": $description",
+              no_mt=>1});
+    }
     &Apache::lonhtmlcommon::add_breadcrumb
-        ({href=>"/adm/$cdom/$cnum/$group/smppg?$refarg",
-          text=>"$ucgpterm: $description",
-          title=>"Go to group's home page"},
-         {href=>"/adm/groupboards?group=$group&amp;$refarg",
+         ({href=>"/adm/groupboards?group=$group&amp;$refarg",
           text=>"Discussion Boards",
           title=>"Display group discussion boards"},);
-    $output .= &Apache::lonhtmlcommon::breadcrumbs(&mt('[_1] discussion boards - [_2]',$gpterm,$description));
+    $output .= &Apache::lonhtmlcommon::breadcrumbs(&mt('Group discussion boards - [_1]',$description),
+                                                   undef,undef,undef,undef,1);
     return $output;
 }
 
