@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Personal Information Page
 #
-# $Id: lonaboutme.pm,v 1.161 2021/11/30 15:55:37 raeburn Exp $
+# $Id: lonaboutme.pm,v 1.161.2.1 2024/07/03 23:49:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -112,7 +112,11 @@ sub handler {
     my $candisplay = 1;
     if (!$is_course) {
         if ($action ne 'portfolio') {
-            $candisplay = &Apache::lonnet::usertools_access($cnum,$cdom,'aboutme');
+            if (($env{'user.name'} eq $cnum) && ($env{'user.domain'} eq $cdom)) {
+                $candisplay = &Apache::lonnet::usertools_access($cnum,$cdom,'aboutme');
+            } else {
+                $candisplay = &Apache::loncommon::aboutme_on($cnum,$cdom);
+            }
             if ((!$candisplay) && ($env{'request.course.id'})) {
                 $candisplay = &aboutme_access($cnum,$cdom);
             }
