@@ -1,6 +1,6 @@
 # The LearningOnline Network
 #
-# $Id: loncourserespicker.pm,v 1.12 2015/04/09 17:57:05 raeburn Exp $
+# $Id: loncourserespicker.pm,v 1.14 2016/10/16 21:49:51 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -75,7 +75,7 @@ select items.  Checking a folder causes recursive checking of items
 within the folder. Unchecking a resource causing unchecking of folders
 containing the item back up to the top level.
 
-Inputs: 9.
+Inputs: 11.
    - $navmap  -- Reference to LON-CAPA navmap object 
                 (encapsulates information about resources in the course). 
 
@@ -106,6 +106,10 @@ Inputs: 9.
 
    - $uploadedfiles -- Reference to hash: keys are paths to files in
                        /home/httpd/lonUsers/$cdom/$1/$2/$3/$cnum/userfiles.
+   
+   - $readonly -- if true, no "check all" or "uncheck all" buttons will
+                  be displayed, and checkboxes will be disabled, if this 
+                  is for an exam block.
 
 
 Output: $output is the HTML mark-up for display/selection of content
@@ -206,7 +210,8 @@ use Apache::lonlocal;
 use LONCAPA qw(:DEFAULT :match);
 
 sub create_picker {
-    my ($navmap,$context,$formname,$crstype,$blockedmaps,$blockedresources,$block,$preamble,$numhome,$uploadedfiles) = @_;
+    my ($navmap,$context,$formname,$crstype,$blockedmaps,$blockedresources,$block,$preamble,
+        $numhome,$uploadedfiles,$readonly) = @_;
     return unless (ref($navmap));
     my ($it,$output,$numdisc,%maps,%resources,%discussiontime,%currmaps,%currresources,%files);
     $it = $navmap->getIterator(undef,undef,undef,1,undef,undef);
@@ -236,12 +241,15 @@ sub create_picker {
     my $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
     my $crsprefix = &propath($cdom,$cnum).'/userfiles/';
 
-    my ($info,$display,$onsubmit,$togglebuttons);
+    my ($info,$display,$onsubmit,$togglebuttons,$disabled);
     if ($context eq 'examblock') {
         my $maps_elem = 'docs_maps_'.$block;
         my $res_elem = 'docs_resources_'.$block;
         $onsubmit = ' onsubmit="return writeToOpener('."'$maps_elem','$res_elem'".');"';
         $info = &mt('Items in '.lc($crstype).' for which access will be blocked.');
+        if ($readonly) {
+            $disabled = ' disabled="disabled"';
+        }
     }
     if ($context eq 'dumpdocs') {
         $info = '<span class="LC_fontsize_medium">'.
@@ -253,10 +261,14 @@ sub create_picker {
         $info = &mt('Choose which items you wish to export from your '.$crstype.'.');
         $startcount = 5;
     }
-    $togglebuttons = '<input type="button" value="'.&mt('check all').'" '.
-                     'onclick="javascript:checkAll(document.'.$formname.'.archive)" />'.
-                     '&nbsp;&nbsp;<input type="button" value="'.&mt('uncheck all').'"'.
-                     ' onclick="javascript:uncheckAll(document.'.$formname.'.archive)" />';
+    if ($disabled) {
+        $togglebuttons = '<br />';
+    } else {
+        $togglebuttons = '<input type="button" value="'.&mt('check all').'" '.
+                         'onclick="javascript:checkAll(document.'.$formname.'.archive)" />'.
+                         '&nbsp;&nbsp;<input type="button" value="'.&mt('uncheck all').'"'.
+                         ' onclick="javascript:uncheckAll(document.'.$formname.'.archive)" />';
+    }
     $display = '<form name="'.$formname.'" action="" method="post"'.$onsubmit.'>'."\n";
     if ($context eq 'imsexport') {
         $display .= $info.
@@ -353,7 +365,7 @@ sub create_picker {
                     $display .= 'checked="checked"';
                 }
             }
-            $display .= ' />'."\n";
+            $display .= $disabled.' />'."\n";
             if ($context eq 'dumpdocs') {
                 $display .= '</td><td valign="top">';
             }
@@ -450,10 +462,12 @@ sub create_picker {
            &mt('Export').'" /></p>';
         $numcount = $count + $boards + $startcount;
     } elsif ($context eq 'examblock') {
-        $display .=
-            '<p>'.
-            '<input type="submit" name="resourceblocks" value="'.
-            &mt('Copy Choices to Main Window').'" /></p>';
+        unless ($readonly) {
+            $display .=
+                '<p>'.
+                '<input type="submit" name="resourceblocks" value="'.
+                &mt('Copy Choices to Main Window').'" /></p>';
+        }
         $numcount = $count + $startcount;
     } elsif ($context eq 'dumpdocs') {
         $display .= '</fieldset>'.
@@ -592,6 +606,9 @@ EXTRA
         my $blankmsg = &mt('An item selected has no filename set in the "Save as ..." column.');
         my $dupmsg = &mt('Items selected for copying need unique filenames in the "Save as ..." column.');
         my $homemsg = &mt('An Authoring Space needs to be selected.');
+        &js_escape(\$blankmsg);
+        &js_escape(\$dupmsg);
+        &js_escape(\$homemsg);
         $scripttag .= <<"EXTRA";
 
 function checkUnique(form,field) {
