@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # gerenates a lon-capa CSS response
 #
-# $Id: loncss.pm,v 1.7 2007/10/02 01:10:27 albertel Exp $
+# $Id: loncss.pm,v 1.9 2011/05/27 21:53:41 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -47,7 +47,8 @@ sub handler {
     $r->content_type('text/css');
     my $date=strftime("%a, %d %b %Y %H:%M:%S GMT",gmtime(time+86400));
     $r->header_out("Expires" => $date);
-
+    $r->header_out("Cache-Control" =>  "public, no-transform");
+    $r->send_http_header;
     
     my $handle = &Apache::lonnet::check_for_valid_session($r);
     if ($handle ne '' ) {
