@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonhelp.pm,v 1.46 2017/04/01 13:55:32 raeburn Exp $
+# $Id: lonhelp.pm,v 1.46.2.1 2024/07/01 23:40:56 raeburn Exp $
 #
 # .tex help system web server handler
 #
@@ -246,8 +246,10 @@ sub handler {
                       };
      }
      my $firstfile;
+     $env{'form.texengine'} = 'tth';
      my $start_page=
 	 &Apache::loncommon::start_page('LON-CAPA Help',undef,$starthash);
+     delete($env{'form.texengine'});
      my $text='';
      my $uri = $r->uri;
      if ($env{'form.searchterm'}=~/\w/) {
