@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Quick Student Grades Display
 #
-# $Id: lonquickgrades.pm,v 1.49.6.8 2021/12/14 02:44:05 raeburn Exp $
+# $Id: lonquickgrades.pm,v 1.49.6.9 2024/07/03 18:51:56 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -193,9 +193,36 @@ ENDCLOSE
         $topLevelRight,$topLevelAttempted) = &getData($showPoints,$uname,$udom);
 
     if (ref($navmap)) {
-        &outputTable($r,$showPoints,$notshowTotals,$navmap,$totalParts,$totalPossible,
-                     $totalRight,$totalAttempted,$topLevelParts,$topLevelRight,
-                     $topLevelAttempted);
+        my $nostdtotals;
+        if ($showPoints) {
+            if ($env{'course.'.$env{'request.course.id'}.'.grading'} eq 'standard') {
+                my $hidetotals = $env{'course.'.$env{'request.course.id'}.'.hidetotals'};
+                if ($hidetotals eq 'all') {
+                    $nostdtotals = 1;
+                } elsif ($hidetotals ne '') {
+                    my $usec;
+                    if ($cangrade) {
+                        if (($uname eq $env{'user.name'}) && ($udom eq $env{'user.domain'})) {
+                            $usec = $env{'request.course.sec'};
+                        } else {
+                            $usec = &Apache::lonnet::getsection($udom,$uname,$env{'request.course.id'});
+                        }
+                    } else {
+                        $usec = $env{'request.course.sec'};
+                    }
+                    if ($usec ne '') {
+                        my %secnototals;
+                        map { $secnototals{$_} = 1; } split(/,/,$hidetotals);
+                        if ($secnototals{$usec}) {
+                            $nostdtotals = 1;
+                        }
+                    }
+                }
+            }
+        }
+        &outputTable($r,$showPoints,$notshowTotals,$nostdtotals,$navmap,
+                     $totalParts,$totalPossible,$totalRight,$totalAttempted,
+                     $topLevelParts,$topLevelRight,$topLevelAttempted);
     } else {
         if ($cangrade) { $r->print("\n</form>\n"); }
         my $requrl = $r->uri;
@@ -370,8 +397,8 @@ sub getData {
 
 sub outputTable {
 
-    my ($r,$showPoints,$notshowTotals,$navmap,$totalParts,$totalPossible,$totalRight,
-        $totalAttempted,$topLevelParts,$topLevelRight,$topLevelAttempted)=@_;
+    my ($r,$showPoints,$notshowTotals,$nostdtotals,$navmap,$totalParts,$totalPossible,
+        $totalRight,$totalAttempted,$topLevelParts,$topLevelRight,$topLevelAttempted)=@_;
 
     my @start = (255, 255, 192);
     my @end   = (0, 192, 0);
@@ -456,16 +483,18 @@ sub outputTable {
 # show totals (if applicable), close table
 #
     if ($showPoints) {
-	my $maxHelpLink = &Apache::loncommon::help_open_topic("Quick_Grades_Possibly_Correct");
+        unless ($nostdtotals) {
+	    my $maxHelpLink = &Apache::loncommon::help_open_topic("Quick_Grades_Possibly_Correct");
 
-	$title = $showPoints ? "Points" : "Parts Done";
-	my $totaltitle = $showPoints ? &mt("Awarded Total Points") : &mt("Total Parts Done");
-	$r->print(&Apache::loncommon::start_data_table_row()
-                 .'<td colspan="2" align="right">'.$totaltitle.': <b>'.$totalRight.'</b><br />');
-	$r->print(&mt('Max Possible To Date')." $maxHelpLink: <b>$totalPossible</b><br />");
-	$title = $showPoints ? "Points" : "Parts";
-	$r->print(&mt("Total $title In Course").': <b>'.$totalParts.'</b></td>'
-                 .&Apache::loncommon::end_data_table_row());
+	    $title = $showPoints ? "Points" : "Parts Done";
+	    my $totaltitle = $showPoints ? &mt("Awarded Total Points") : &mt("Total Parts Done");
+	    $r->print(&Apache::loncommon::start_data_table_row()
+                     .'<td colspan="2" align="right">'.$totaltitle.': <b>'.$totalRight.'</b><br />');
+	    $r->print(&mt('Max Possible To Date')." $maxHelpLink: <b>$totalPossible</b><br />");
+	    $title = $showPoints ? "Points" : "Parts";
+	    $r->print(&mt("Total $title In Course").': <b>'.$totalParts.'</b></td>'
+                     .&Apache::loncommon::end_data_table_row());
+        }
     }
 
     $r->print(&Apache::loncommon::end_data_table());
@@ -486,6 +515,8 @@ sub startGradeScreen {
 
     my $showPoints =
         $env{'course.'.$env{'request.course.id'}.'.grading'} eq 'standard';
+    my $hidetotals =
+        $env{'course.'.$env{'request.course.id'}.'.hidetotals'};
     my $notshowSPRSlink =
         (($env{'course.'.$env{'request.course.id'}.'.grading'} eq 'external')
       || ($env{'course.'.$env{'request.course.id'}.'.grading'} eq 'externalnototals'));
@@ -511,6 +542,20 @@ sub startGradeScreen {
         push(@notes,&mt('Students do not see total points.')) if ($notshowTotals);
         push(@notes,&mt('Students do not see link to spreadsheet.')) if ($notshowSPRSlink);
         push(@notes,&mt('Students will see points based on problem weights.')) if ($showPoints);
+        if (($showPoints) && ($hidetotals ne '')) {
+            if ($hidetotals eq 'all') {
+                push(@notes,&mt('Students do not see course totals.'));
+            } else {
+                my @secs = split(/,/,$hidetotals);
+                if (@secs == 1) {
+                    push(@notes,&mt('Students in section [_1] do not see course totals.',
+                                    $hidetotals));
+                } elsif (@secs > 1) {
+                    push(@notes,&mt('Students in sections [_1] do not see course totals.',
+                                    join(', ',@secs)));
+                }
+            }
+        }
         push(@notes,&mt('Students will see link to spreadsheet.')) if ($showSPRSlink);
         push(@notes,&Apache::lonhtmlcommon::coursepreflink(&mt('Grade display settings'),'grading'));
         $r->print(&Apache::loncommon::head_subbox(join('&nbsp;&nbsp;',@notes)));
