@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lontrackstudent.pm,v 1.38 2014/11/24 02:36:30 raeburn Exp $
+# $Id: lontrackstudent.pm,v 1.40 2017/11/12 23:06:51 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -185,7 +185,7 @@ sub get_max_time_in_db {
     &Apache::lonhtmlcommon::Update_PrgWin
         ($r,$prog_state,&mt('Parsing results'));
     #
-    if (! open(TIMEDATA,$results_file)) {
+    if (! open(TIMEDATA,"<",$results_file)) {
         $r->print('<p class="LC_error">'.&mt('Unable to read results file.').'</p>'.
                   '<p>'.
                   &mt('This is a serious error and has been logged.').
@@ -254,7 +254,7 @@ sub output_results {
         $r->print('<p class="LC_info">'.&mt('So far, no data has been returned for your request').'</p>');
         return -1;
     }
-    if (! open(ACTIVITYDATA,$results_file)) {
+    if (! open(ACTIVITYDATA,"<",$results_file)) {
         $r->print('<p class="LC_error">'.&mt('Unable to read results file.').'</p>'.
                   '<p>'.
                   &mt('This is a serious error and has been logged.').
@@ -580,6 +580,7 @@ sub handler {
     my $args;
     if ($env{'form.only_body'}) {
         $args = { only_body => 1, };
+        $args->{'add_progressbar'} = 1;
     }
     $r->print(&Apache::loncommon::start_page('Student Activity',&styles(),$args).
               &Apache::lonhtmlcommon::breadcrumbs('Student Activity'));
