@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Allow users to self-enroll in a course
 #
-# $Id: selfenroll.pm,v 1.27.2.6 2020/01/09 17:36:09 raeburn Exp $
+# $Id: selfenroll.pm,v 1.27.2.8 2021/12/14 12:53:12 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -456,7 +456,7 @@ sub process_self_enroll {
         }
         if ($selfenroll_approval) {
             my $outcome = 
-                &store_selfenroll_request($udom,$uname,$usec,$cdom,$cnum,
+                &store_selfenroll_request($r,$udom,$uname,$usec,$cdom,$cnum,
                                           $selfenroll_notifylist,$owner,
                                           $selfenroll_approval,$crstype,$lonhost,$handle);
             $r->print($outcome);
@@ -536,7 +536,7 @@ sub user_can_selfenroll {
 }
 
 sub store_selfenroll_request {
-    my ($udom,$uname,$usec,$cdom,$cnum,$selfenroll_notifylist,$owner,
+    my ($r,$udom,$uname,$usec,$cdom,$cnum,$selfenroll_notifylist,$owner,
         $selfenroll_approval,$crstype,$lonhost,$handle) = @_;
     my $namespace = 'selfenrollrequests';
     my $output;
@@ -552,7 +552,7 @@ sub store_selfenroll_request {
         }
         if ($status eq 'pending') {
             my $token = $info{$cdom.'_'.$cnum}{'token'};
-            my ($statusupdate,$pendingform) = &pending_selfenrollment_form($cdom,$cnum,$crstype,$token,$lonhost);
+            my ($statusupdate,$pendingform) = &pending_selfenrollment_form($r,$cdom,$cnum,$crstype,$token,$lonhost);
             if ($statusupdate eq 'pending') {
                 $output .= $pendingform;
             }
@@ -590,7 +590,7 @@ sub store_selfenroll_request {
             }
             $output = &mt('Your request for self-enrollment has been recorded.').'<br />';
             if ($status eq 'pending') {
-                my ($statusupdate,$pendingform) = &pending_selfenrollment_form($cdom,$cnum,$crstype,$token,$lonhost);
+                my ($statusupdate,$pendingform) = &pending_selfenrollment_form($r,$cdom,$cnum,$crstype,$token,$lonhost);
                 if ($statusupdate eq 'request') {
                     $status = $statusupdate;
                 } else {
@@ -631,7 +631,7 @@ sub store_selfenroll_request {
 }
 
 sub pending_selfenrollment_form {
-    my ($cdom,$cnum,$crstype,$token,$lonhost) = @_;
+    my ($r,$cdom,$cnum,$crstype,$token,$lonhost) = @_;
     my ($status,$output);
     my $coursetype = &Apache::lonuserutils::get_extended_type($cdom,$cnum,$crstype);
     my %postvalues = (
@@ -668,6 +668,8 @@ sub pending_selfenrollment_form {
                 my $hostname = &Apache::lonnet::hostname($lonhost);
                 my $protocol = $Apache::lonnet::protocol{$lonhost};
                 $protocol = 'http' if ($protocol ne 'https');
+                my $alias = &Apache::lonnet::use_proxy_alias($r,$lonhost);
+                $hostname = $alias if ($alias ne '');
                 my $enroller = $protocol.'://'.$hostname.'/cgi-bin/enrollqueued.pl';
                 $output .= '<input type="hidden" name="enroller" value="'.$enroller.'" />'."\n".
                            '<input type="hidden" name="token" value="'.$token.'" />'."\n".
@@ -793,7 +795,7 @@ sub check_registered {
                                         'internal.sectionnums',
                                         'internal.crosslistings'],$cdom,$cnum);
     my (@allcourses,%LC_code,%affiliates,%reply);
-    &Apache::loncommon::get_institutional_codes(\%settings,\@allcourses,\%LC_code);
+    &Apache::loncommon::get_institutional_codes($cdom,$cnum,\%settings,\@allcourses,\%LC_code);
     if (@allcourses > 0) {
         @{$affiliates{$cnum}} = @allcourses;
         my $outcome = &Apache::lonnet::fetch_enrollment_query('updatenow',\%affiliates,\%reply,$cdom,$cnum);
