@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Farsi Localization Lexicon
 #
-# $Id: fa.pm,v 1.18 2011/05/27 14:39:56 bisitz Exp $
+# $Id: fa.pm,v 1.27 2014/02/28 19:22:07 bisitz Exp $
 #
 # Copyright i-Learning Limited Partnership Company
 #
@@ -40,45 +40,43 @@ use base qw(Apache::localize);
 'date_days'    => 'يكشنبه,دوشنبه,سه شنبه,چهارشنبه,پنجشنبه,جمعه,شنبه',
 'date_am' => 'قبل از ظهر',
 'date_pm' => 'بعد از ظهر',
-'textual_remote_display' => 'on',
 
+   'Deutsch - UTF' # do not translate
+=> 'Deutsch - UTF',
 
-   'Arabic - UTF'
-=> 'ﺎﻠﻋﺮﺒﻳﺓ - UTF',
+   'English - UTF' # do not translate
+=> 'English - UTF',
 
-   'German - UTF'
-=> 'Deutsch - UTF', # 'UTF زبان آلمانى'
+   'Português - UTF' # do not translate
+=> 'Português - UTF',
 
-   'English - UTF'
-=> 'English - UTF', # 'UTF - انگليسى '
-
-   'Spanish (Castellan) - UTF'
+   'español (castellano) - UTF' # do not translate
 => 'español (castellano) - UTF',
 
-   'Persian - UTF'
-=> 'ﺍیﺭﺎﻧی - UTF',
-
-   'French - UTF'
+   'français - UTF' # do not translate
 => 'français - UTF',
 
-   'Hebrew - UTF'
+   'türkçe - UTF' # do not translate
+=> 'türkçe - UTF',
+
+   'Русский - UTF' # do not translate
+=> 'Русский - UTF',
+
+   'עברית - UTF' # do not translate
 => 'עברית - UTF',
 
-   'Japanese - UTF'
-=> '日本語 - UTF', # 'UTF - ژاپنى'
+   '日本語 - UTF' # do not translate
+=> '日本語 - UTF',
 
-   'Portuguese - UTF'
-=> 'Português - UTF', # 'UTF - زبان پرتغالى'
-
-   'Russian - UTF'
-=> 'Русский - UTF', # 'UTF - زبان روسى'
-
-   'Turkish - UTF'
-=> 'türkçe - UTF', # 'UTF - تركى'
-
-   'Chinese Simplified - UTF'
+   '简体中文 - UTF' # do not translate
 => '简体中文 - UTF',
 
+   'ﺍیﺭﺎﻧی - UTF' # do not translate
+=> 'ﺍیﺭﺎﻧی - UTF',
+
+   'ﺎﻠﻋﺮﺒﻳﺓ - UTF' # do not translate
+=> 'ﺎﻠﻋﺮﺒﻳﺓ - UTF',
+
    'Swedish Chef - UTF'
 => 'Swedish Chef - UTF',
 
@@ -439,9 +437,6 @@ use base qw(Apache::localize);
    'Goodbye'
 => 'خداحافظ',
 
-   ', and answers will be available on'
-=> ', و پاسخها  در دسترس خواهد بود',
-
    ', or the next time you log in.'
 => ', يا دفعه بعدى كه متصل شويد',
 
@@ -481,7 +476,7 @@ use base qw(Apache::localize);
    'Back to Directory'
 => 'بازگشت به فهرست راهنما',
 
-   'Bulletin Board'
+   'Discussion Board'
 => 'تابلوى اعلانات',
 
    'Cancel'
@@ -490,8 +485,8 @@ use base qw(Apache::localize);
    'Changes will become active for your current session after'
 => 'تغييرات براى جلسه فعلى شما فعال خواهد شد بعد از اين كه',
 
-   'Construction Space Directory'
-=> 'فهرست راهنماى فضا طرح',
+   'Authoring Space Directory'
+=> 'Authoring Space Directory', # 'فهرست راهنماى فضا طرح',
 
    'Contact'
 => 'تماس',
@@ -685,8 +680,8 @@ use base qw(Apache::localize);
    'Select a'
 => 'انتخاب يك',
 
-   'Select the Construction Space'
-=> 'انتخاب فضاى طرح',
+   'Select the Authoring Space'
+=> 'Select the Authoring Space', # 'انتخاب فضاى طرح',
 
    'Sequence'
 => 'توالى',
@@ -811,8 +806,8 @@ use base qw(Apache::localize);
    'is closed but you are allowed to view it'
 => 'بسته مى‏شود ولى مجاز هستيد آن را ببينيد',
 
-   'is due at'
-=> 'مقرر است در',
+   'is due at [_1]'
+=> 'مقرر است در [_1]',
 
    'is in under construction'
 => 'در حال آماده سازى است',
@@ -859,11 +854,11 @@ use base qw(Apache::localize);
    'undo'
 => 'بى اثر كردن',
 
-   'was due on'
-=> 'مقرر بود در',
+   'was due on [_1], and answers will be available on [_2]'
+=> 'مقرر بود در [_1], ﻭ پﺎﺴﺨﻫﺍ  ﺩﺭ ﺪﺴﺗﺮﺳ ﺥﻭﺎﻫﺩ ﺏﻭﺩ [_2]',
 
-   'will open on'
-=> 'در این تاريخ باز خواهد شد',
+   'will open on [_1]'
+=> 'در این تاريخ باز خواهد شد [_1]',
 
    ', is reserved internally by LON-CAPA.'
 => ', در درون توسط لون كاپا ذخيره مى‏شود',
@@ -892,7 +887,7 @@ use base qw(Apache::localize);
    'Customized right of use ...'
 => 'حق سفارشى استفاده',
 
-   'Delete messages from bulletin boards'
+   'Delete messages from discussion boards'
 => 'حذف نامه‏ها از تابلوى اعلانات',
 
    'Domain only - use limited to courses in the domain'
@@ -907,8 +902,8 @@ use base qw(Apache::localize);
    'Edit/Modify DOCS'
 => ' DOC ويرايش يا تغيير فايلهاى با پسوند',
 
-   'Enter my resource construction space'
-=> 'ورود به فضاى طرح منبع من',
+   'Enter my Authoring Space'
+=> 'Enter my Authoring Space', # 'ورود به فضاى طرح منبع من',
 
    'FAIL'
 => 'ناكامى',
@@ -967,8 +962,8 @@ use base qw(Apache::localize);
    'Public - no authentication or authorization required for use'
 => 'عمومى - براى استفاده نيازى به تأييد و اجازه نيست',
 
-   'Retrieval of an old version will overwrite the file currently in construction space'
-=> 'بازيابى نسخه قديمى مستلزم رونويسى بر فايلى است كه هم اكنون در فضاى طرح است',
+   'Retrieval of an old version will overwrite the file currently in Authoring Space.'
+=> 'Retrieval of an old version will overwrite the file currently in Authoring Space.', # 'بازيابى نسخه قديمى مستلزم رونويسى بر فايلى است كه هم اكنون در فضاى طرح است',
 
    'Retrieve previous versions of'
 => 'بازيابى نسخه‏هاى قبلىِ',
@@ -1052,8 +1047,8 @@ use base qw(Apache::localize);
    'Collapse Remote Control'
 => 'بر هم زدن كنترل از راه دور',
 
-   'Construction Space'
-=> 'فضاى طرح',
+   'Authoring Space'
+=> 'Authoring Space', # 'فضاى طرح',
 
    'Content changed'
 => 'محتوا تغيير كرد',
@@ -1088,8 +1083,8 @@ use base qw(Apache::localize);
    'Differences'
 => 'تفاوتها',
 
-   'Dump Course DOCS to Construction Space'
-=> '(doc) دور ريختن فايلهاى  موجود در فضاى طرح',
+   'Copy Course Content to Authoring Space'
+=> 'Copy Course Content to Authoring Space', # '(doc) دور ريختن فايلهاى  موجود در فضاى طرح',
 
    'Entering course ...'
 => ' ... در حال ورود به دوره',
@@ -1492,8 +1487,11 @@ use base qw(Apache::localize);
    '<b>[_1]</b>: Unable to enroll.  No password specified.'
 => '<b>[_1]</b>: ثبت نام ميسر نشد. رمز عبور مشخص نشده ا',
 
-   '<b>[_1]</b>: Unacceptable username for user [_2] [_3] [_4] [_5]'
-=> '<b>[_1]</b>: نام كاربرى براى اين كاربر غير قابل قبول استr [_2] [_3] [_4] [_5]',
+   'Unacceptable username [_1] for user [_2] [_3] [_4] [_5]'
+=> 'نام كاربرى براى اين كاربر غير قابل قبول است [_1] [_2] [_3] [_4] [_5]',
+
+   'Unacceptable domain [_1] for user [_2] [_3] [_4] [_5]'
+=> 'Unacceptable domain [_1] for user [_2] [_3] [_4] [_5]',
 
    'ALL'
 => 'همه',
@@ -1594,7 +1592,7 @@ use base qw(Apache::localize);
    'Browsing resource, all submissions are temporary.'
 => 'در حال مرور منبع، كليه تقاضاها موقتى هستند',
 
-   'Bulletin Board/Discussion'
+   'Discussion Board/Discussion'
 => 'تابلوى اعلانات / مباحثه',
 
    'By'
@@ -1675,8 +1673,8 @@ use base qw(Apache::localize);
    'Concepts'
 => 'مفاهيم',
 
-   'Construction Space File Operation'
-=> 'عمليات فايل طرح فضا',
+   'Authoring Space File Operation'
+=> 'Authoring Space File Operation', # 'عمليات فايل طرح فضا',
 
    'Contact Information'
 => 'اطلاعات تماس',
@@ -1870,8 +1868,8 @@ use base qw(Apache::localize);
    'Enrollment Status'
 => 'وضعيت ثبت نام',
 
-   'Enter construction space as a co-author'
-=> 'ورود به فضاى طرح به عنوان همكار نويسنده',
+   'Enter Authoring Space as a co-author'
+=> 'Enter Authoring Space as a co-author', # 'ورود به فضاى طرح به عنوان همكار نويسنده',
 
    'Error'
 => 'خطا',
@@ -1888,8 +1886,8 @@ use base qw(Apache::localize);
    'Excel'
 => 'اكسل',
 
-   'Failed Access to Construction Space'
-=> 'دسترسى به فضاى طرح ميسر نشد',
+   'Failed Access to Authoring Space'
+=> 'Failed Access to Authoring Space', # 'دسترسى به فضاى طرح ميسر نشد',
 
    'False'
 => 'نادرست',
@@ -1903,8 +1901,8 @@ use base qw(Apache::localize);
    'File Category'
 => 'مقوله فايل',
 
-   'Filenames in Construction Space'
-=> 'نام فايل در فضاى طرح',
+   'Filenames in Authoring Space'
+=> 'Filenames in Authoring Space', # 'نام فايل در فضاى طرح',
 
    'Finish Course Initialization'
 => 'اتمام مقدار دهى اوليه دوره',
@@ -1921,8 +1919,8 @@ use base qw(Apache::localize);
    'Folder'
 => 'پوشه',
 
-   'Folder in Construction Space'
-=> 'پوشه در فضاى طرح',
+   'Folder in Authoring Space'
+=> 'Folder in Authoring Space', # 'پوشه در فضاى طرح',
 
    'For User'
 => 'براى كاربر',
@@ -2320,8 +2318,14 @@ use base qw(Apache::localize);
    'Problems Not Contained In A Folder'
 => 'مسائل در يك پوشه جا داده نشده اند',
 
-   'Problems creating new Excel file.  This error has been logged.  Please alert your LON-CAPA administrator.'
-=> 'مسائل ايجاد كننده فايل اكسل جديد. اين خطا ثبت شده است. لطفاً به مدير لون كاپا هشدار دهيد',
+   'Problems occurred in creating the new Excel file.'
+=> 'مسائل ايجاد كننده فايل اكسل جديد.',
+
+   'This error has been logged.'
+=> 'ﺎﻴﻧ ﺦﻃﺍ ﺚﺒﺗ ﺵﺪﻫ ﺎﺴﺗ.',
+
+   'Please alert your LON-CAPA administrator.'
+=> 'ﻞﻄﻓﺍً ﺐﻫ ﻡﺪﻳﺭ ﻝﻮﻧ ﻙﺍپﺍ ﻪﺷﺩﺍﺭ ﺪﻬﻳﺩ.',
 
    'Processed [_1] student(s).'
 => 'پردازش شده [1_] دانشجويان',
@@ -2512,7 +2516,7 @@ use base qw(Apache::localize);
    'Set an open date'
 => 'تنظيم يك تاريخ اُپِن',
 
-   'Set opening datefor all problems in the course for. . .'
+   'Set opening date for all problems in the course for. . .'
 => 'تعيين تاريخ شروع همه مسائل در دوره به منظور',
 
    'Set the number of tries'
