@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Localization routines
 #
-# $Id: lonlocal.pm,v 1.66 2015/06/09 21:23:15 damieng Exp $
+# $Id: lonlocal.pm,v 1.67 2019/02/24 01:38:14 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -38,7 +38,7 @@ Apache::lonlocal - provides localization services
 
 lonlocal provides localization services for LON-CAPA programmers based
 on Locale::Maketext. See
-C<http://search.cpan.org/dist/Locale-Maketext/lib/Locale/Maketext.pod>
+C<https://metacpan.org/pod/Locale::Maketext>
 for more information on Maketext.
 
 =head1 OVERVIEWX<internationalization>
@@ -153,7 +153,7 @@ ignore the rest of the line.
 This is a relatively easy task, and any help is appreciated.
 
 Maketext can do a whole lot more, see
-C<http://search.cpan.org/dist/Locale-Maketext/lib/Locale/Maketext.pod>
+C<https://metacpan.org/pod/Locale::Maketext>
 but for most purposes, we do not have to mess with that.
 
 =cut
@@ -496,9 +496,11 @@ sub getdatelocale {
     return $locale_obj;
 }
 
-=pod 
+=pod
 
-=item * normalize_string
+=over 
+
+=item * normalize_string()
 
 Normalize string (reduce fragility in the lexicon files)
 
@@ -521,7 +523,7 @@ sub normalize_string {
 
 =pod 
 
-=item * ns
+=item * ns()
 
 alias for normalize_string; recommend using it only in the lexicon
 
@@ -533,7 +535,7 @@ sub ns {
 
 =pod
 
-=item * mtn
+=item * mtn()
 
 mtn: call the mt function and the normalization function easily.
 Returns original non-normalized string if there was no translation
@@ -562,7 +564,7 @@ sub transstatic {
 
 =pod 
 
-=item * mt_escape
+=item * mt_escape()
 
 mt_escape takes a string reference and escape the [] in there so mt
 will leave them as is and not try to expand them
@@ -577,7 +579,7 @@ sub mt_escape {
 
 =pod 
 
-=item * js_escape
+=item * js_escape()
 
 js_escape takes a string, string reference or hash reference,
 and escapes the values so that they can be used within a <script> element.
@@ -612,7 +614,7 @@ sub js_escape {
 
 =pod 
 
-=item * html_escape
+=item * html_escape()
 
 js_escape takes a string, string reference or hash reference,
 and escapes the values so that they can be used as HTML.
@@ -650,11 +652,13 @@ sub html_escape {
 
 =pod
 
-=item * choose_language
+=item * choose_language()
 
 choose_language prompts a user to enter a two letter language code via
 keyboard when running a script from the command line. Default is en.
 
+=back
+
 =cut
 
 sub choose_language {
