@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.112.2.6 2016/08/05 21:24:01 raeburn Exp $
+# $Id: lontexconvert.pm,v 1.112.2.9 2019/02/15 21:21:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -270,11 +270,19 @@ sub displaystyle {
 
 sub MathJax_converted {
     my $texstring=shift;
-    my $tag='math/tex;';
-    if (&displaystyle($texstring)) { $tag='math/tex; mode=display'; }
+    my ($tag,$startspan,$endspan);
+    $tag='math/tex;';
+    if (&displaystyle($texstring)) {
+        $tag='math/tex; mode=display';
+        $startspan='';
+        $endspan='';
+    } else {
+        $startspan='<span style="display:inline-block;">';
+        $endspan='</span>';
+    }
     &clean_out_math_mode($texstring);
-    return &MathJax_header().
-      '<script type="'.$tag.'">'.$$texstring.'</script>';
+    return &MathJax_header().$startspan.
+      '<script type="'.$tag.'">'.$$texstring.'</script>'.$endspan;
 }
 
 {
@@ -320,7 +328,12 @@ sub tex_engine {
         }
 	return $env{'environment.texengine'};
     }
-    return 'tth';
+    my $dom = $env{'request.role.domain'} || $env{'user.domain'};
+    my %domdefaults = &Apache::lonnet::get_domain_defaults($dom);
+    if ($domdefaults{'texengine'} ne '') {
+        return $domdefaults{'texengine'};
+    }
+    return $Apache::lonnet::deftex;
 }
 
 sub init_math_support {
