@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.111.2.13 2020/11/11 21:52:05 raeburn Exp $
+# $Id: lonpage.pm,v 1.111.2.16 2024/07/03 02:38:40 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -101,7 +101,9 @@ sub tracetable {
             } else {
                 $sofar++;
                 if ($hash{'src_'.$rid}) {
-                    my $brepriv=&Apache::lonnet::allowed('bre',$hash{'src_'.$rid});
+                    my ($mapid,$resid)=split(/\./,$rid);
+                    my $symb = &Apache::lonnet::encode_symb($hash{'map_id_'.$mapid},$resid,$hash{'src_'.$rid});
+                    my $brepriv=&Apache::lonnet::allowed('bre',$hash{'src_'.$rid},$symb);
                     if (($brepriv eq '2') || ($brepriv eq 'F')) {
                         if (defined($rows[$sofar])) {
                             $rows[$sofar].='&'.$rid;
@@ -236,6 +238,7 @@ sub handler {
                   my $nforms=0;
                   my $nuploads=0;
                   my $ntimers=0;
+                  my $hasnumresp;
                   my %turninpaths;
                   my %multiresps;
                   my $turninparent;
@@ -473,6 +476,11 @@ ENDEXT
                                       $ntimers++;
                                       $hastimer = 1;
                                   }
+                                  unless ($hasnumresp) {
+                                      if ($output=~/\<input[^\>]+class\s*=\s*['"]*[^'">]*LC_numresponse_text\W/) {
+                                          $hasnumresp = 1;
+                                      }
+                                  }
                                   $output=~
 				      s/\<((?:input|select|button|textarea)[^\>]+)name\s*\=\s*[\'\"]*([^\'\"]+)[\'\"]*([^\>]*)\>/\<$1 name="$prefix$2" $3\>/gsi;
                                   $output=~
@@ -603,7 +611,7 @@ ENDEXT
 # ---------------------------------------------------------------- End SSI cell
                           }
                       }
-                     } 
+                     }
                   }
                   unless ($contents) {
                       &Apache::loncommon::content_type($r,'text/html');
@@ -854,8 +862,11 @@ ENDEXT
                           &mt('Processing your submission ...').'</div></form>');
                       }
 		      unless (($target eq 'tex') || ($target eq 'tex_answer')) {
-			  $r->print(&Apache::loncommon::end_page({'discussion'
-								      => 1,}));
+                          my $args = {'discussion' => 1};
+                          if ($hasnumresp) {
+                              $args->{'dashjs'} = 1;
+                          }
+			  $r->print(&Apache::loncommon::end_page($args));
 		      } else {
 			  $r->print('\end{document}'.$number_of_columns);
 		      }
@@ -866,9 +877,30 @@ ENDEXT
                   }                  
 # ------------------------------------------------------------- End render page
               } else {
-                  &Apache::loncommon::content_type($r,'text/html');
-                  $r->send_http_header;
-                  &Apache::lonsequence::viewmap($r,$requrl);
+                  if ($hash{'map_type_'.$hash{'map_pc_'.$requrl}} eq 'none') {
+                      &Apache::loncommon::content_type($r,'text/html');
+                      $r->send_http_header;
+                      $r->print(&Apache::loncommon::start_page(undef,undef,
+                                                               {'force_register' => 1,}));
+                      my $crstype = &Apache::loncommon::course_type();
+                      if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
+                          $r->print('<span class="LC_warning">'.&mt('Missing composite page file.').'</span><br />'.
+                                    &mt("You may want to use the $crstype Editor to remove this item."));
+                      } else {
+                          if ($crstype eq 'Placement') {
+                              $r->print('<span class="LC_warning">'.&mt('Missing page').'</span>');
+                          } else {
+                              $r->print('<span class="LC_info">'.
+                                        &mt('This resource was unavailable when your '.lc($crstype).' session was loaded').'<br />'.
+                                        &mt("Please use 'Contents' to list items available in the $crstype.").'</span>');
+                          }
+                      }
+                      $r->print(&Apache::loncommon::end_page());
+                  } else {
+                      &Apache::loncommon::content_type($r,'text/html');
+                      $r->send_http_header;
+                      &Apache::lonsequence::viewmap($r,$requrl);
+                  }
               }
 # ------------------------------------------------------------------ Untie hash
               unless (untie(%hash)) {
@@ -894,16 +926,18 @@ sub get_buttons {
     my $symb=&Apache::lonnet::encode_symb($hash->{'map_id_'.$mapid},
 					  $resid,
 					  $hash->{'src_'.$rid});
-    my $aname;
+    my ($aname,$shownsymb);
     if (($hash->{'encrypted_'.$rid}) && (!$env{'request.role.adv'})) {
         $aname = 'LC_'.$rid;
+        $shownsymb = &Apache::lonenc::encrypted($symb);
     } else {
-        my $shownsymb = $symb;
+        $shownsymb = $symb;
+        my $dispsymb = $symb;
         if ($symb =~ /\#([^\#]+)$/) {
             my $escan = &escape('#');
-            $shownsymb =~ s/#([^\#]+)$/$escan$1/;
+            $dispsymb =~ s/#([^\#]+)$/$escan$1/;
         }
-        $aname = &escape($shownsymb);
+        $aname = &escape($dispsymb);
     }
     my $metainfo = '<a name="'.$aname.'"></a>';
     unless ($env{'request.role.adv'}) {
@@ -986,8 +1020,8 @@ sub get_buttons {
                 &Apache::lonnet::can_edit_resource($file,$cnum,$cdom,$hash->{'src_'.$rid},$symb);
             if ($cfile ne '') {
                 my $jscall = &Apache::lonhtmlcommon::jump_to_editres($cfile,$home,$switchserver,
-                                                                     $forceedit,1,$symb,undef,
-                                                                     &escape($env{'form.title'}),
+                                                                     $forceedit,1,$symb,$shownsymb,
+                                                                     undef,&escape($env{'form.title'}),
                                                                      $hostname);
                 if ($jscall) {
                     $editbutton = 1;
