@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Edit Handler for RAT Maps
 #
-# $Id: lonratedt.pm,v 1.105.2.6 2014/02/26 18:52:37 raeburn Exp $
+# $Id: lonratedt.pm,v 1.105.2.7 2015/03/11 21:09:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -755,7 +755,7 @@ sub viewmap {
             $r->print('</td><td>');
             if ($url) {
                $r->print('<a href="'.$cstrurl.'">'.
-                         &mt('Authoring space').'</a>');
+                         &mt('Authoring Space').'</a>');
             } else {
                 $r->print('&nbsp;');
             }
